summaryrefslogtreecommitdiffstats
path: root/tderesources/scalix/kabc/resourcescalix.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tderesources/scalix/kabc/resourcescalix.cpp')
-rw-r--r--tderesources/scalix/kabc/resourcescalix.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/tderesources/scalix/kabc/resourcescalix.cpp b/tderesources/scalix/kabc/resourcescalix.cpp
index 42aef92d..13ee99ec 100644
--- a/tderesources/scalix/kabc/resourcescalix.cpp
+++ b/tderesources/scalix/kabc/resourcescalix.cpp
@@ -38,8 +38,8 @@
#include <klocale.h>
#include <kmessagebox.h>
#include <ktempfile.h>
-#include <kio/observer.h>
-#include <kio/uiserver_stub.h>
+#include <tdeio/observer.h>
+#include <tdeio/uiserver_stub.h>
#include <kmainwindow.h>
#include <kapplication.h>
#include <dcopclient.h>
@@ -193,8 +193,8 @@ bool KABC::ResourceScalix::loadSubResourceHelper( const TQString& subResource,
// If it's too big the progressbar is jumpy.
const int nbMessages = 200;
- (void)Observer::self(); // ensure kio_uiserver is running
- UIServer_stub uiserver( "kio_uiserver", "UIServer" );
+ (void)Observer::self(); // ensure tdeio_uiserver is running
+ UIServer_stub uiserver( "tdeio_uiserver", "UIServer" );
int progressId = 0;
if ( count > 200 ) {
progressId = uiserver.newJob( kapp->dcopClient()->appId(), true );